==> kabaret.core-0.0.0a3.zip: kabaret.core-0.0.0a3/setup.py <==

import sys
from setuptools import setup

# use the version of the framework package as the base version:
try:
    import kabaret.version
except ImportError:
    version = '0.0.0a1'
else:
    version = kabaret.version.get()


if not hasattr(sys, 'version_info') or sys.version_info < (2, 6, 0, 'final'):
    raise SystemExit("Kabaret requires Python 2.6 or later.")

install_requires = ['pyro4']

setup(
    name='kabaret.core',
    namespace_packages=['kabaret'],
    packages=[
        'kabaret',
        'kabaret.core', 
            'kabaret.core.admin', 
                'kabaret.core.admin.projects',
            'kabaret.core.apphost',
            'kabaret.core.apps', 
            'kabaret.core.cmdln', 
            'kabaret.core.conf',
            'kabaret.core.events',
            'kabaret.core.log',
            'kabaret.core.project',
            'kabaret.core.ro',
            'kabaret.core.station_config',
            'kabaret.core.utils', 
    ],
    version=version,
    install_requires=install_requires,
    description='Base package for the kabaret framework.',
    url='http://packages.python.org/kabaret',
    author='Damien Coureau',
    author_email='dee@dee909.com',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        
        'Topic :: Office/Business :: Groupware',
        'Topic :: Office/Business :: Scheduling',
        
        'Intended Audience :: Developers',
        'Intended Audience :: End Users/Desktop',
        'Intended Audience :: Information Technology',
        
        'Operating System :: OS Independent',
        
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        
        'License :: OSI Approved :: GNU Lesser General Public License v3 or later (LGPLv3+)',
    ],
)

==> kabaret.core-0.1.0b3.zip: kabaret.core-0.1.0b3/setup.py <==

import sys
from setuptools import setup

# (
#    (Major, Minor, [Micros]),
#    [(Alpha/Beta/rc marker, version)],
# )
__version_info__ = ((0, 1, 0), ('b', 3))

def get_version():
    global __version_info__
    return (
        '.'.join(str(x) for x in __version_info__[0]) 
        +''.join(str(x) for x in __version_info__[1])
    )
        
if not hasattr(sys, 'version_info') or sys.version_info < (2, 6, 0, 'final'):
    raise SystemExit("Kabaret requires Python 2.6 or later.")

install_requires = ['pyro4==4.18', 'kabaret']

setup(
    name='kabaret.core',
    namespace_packages=['kabaret'],
    packages=[
        'kabaret',
        'kabaret.core', 
            'kabaret.core.apphost',
            'kabaret.core.apps', 
            'kabaret.core.cmdln', 
            'kabaret.core.conf',
            'kabaret.core.events',
            'kabaret.core.log',
            'kabaret.core.project',
            'kabaret.core.ro',
            'kabaret.core.scripts', 
            'kabaret.core.syscmd', 
            'kabaret.core.utils', 
    ],
    entry_points={
        'console_scripts': [
            'kabadmin = kabaret.core.scripts.kabadmin:main',
        ]
    },
    include_package_data=True, # needed for core/conf/test_config
    version=get_version(),
    install_requires=install_requires,
    description='Base package for the kabaret framework.',
    url='http://packages.python.org/kabaret',
    author='Damien Coureau',
    author_email='dee@dee909.com',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        
        'Topic :: Office/Business :: Groupware',
        'Topic :: Office/Business :: Scheduling',
        
        'Intended Audience :: Developers',
        'Intended Audience :: End Users/Desktop',
        'Intended Audience :: Information Technology',
        
        'Operating System :: OS Independent',
        
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        
        'License :: OSI Approved :: GNU Lesser General Public License v3 or later (LGPLv3+)',
    ],
)
